@@ -124,6 +124,7 @@ static void
 gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 {
 	GeditCloseConfirmationDialogPrivate *priv;
+	AtkObject *atk_obj;
 
 	priv = GEDIT_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE (dlg);
 
@@ -146,7 +147,9 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 				GTK_STOCK_SAVE, GTK_RESPONSE_YES, NULL);
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (dlg), GTK_RESPONSE_YES);
-	atk_object_set_role (gtk_widget_get_accessible (GTK_WIDGET (dlg)), ATK_ROLE_ALERT);
+	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (dlg));
+	atk_object_set_role (atk_obj, ATK_ROLE_ALERT);
+	atk_object_set_name (atk_obj, _("Question"));
 }
 
 static void 
@@ -548,7 +551,6 @@ save_toggled (GtkCellRendererToggle *renderer, gchar *path_str, GtkTreeModel *st
 	gtk_tree_path_free (path);
 }
 
-
 static GtkWidget *
 create_treeview (GeditCloseConfirmationDialogPrivate *priv)
 {
@@ -637,9 +639,13 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
 
-	str = g_strdup_printf (_("There are %d documents with unsaved changes. "
-				 "Save changes before closing?"),
-			       g_slist_length (priv->unsaved_documents));
+	str = g_strdup_printf (
+			ngettext ("There is %d document with unsaved changes. "
+				  "Save changes before closing?",
+				  "There are %d documents with unsaved changes. "
+				  "Save changes before closing?",
+				  g_slist_length (priv->unsaved_documents)),
+			g_slist_length (priv->unsaved_documents));
 	
 	markup_str = g_strconcat ("<span weight=\"bold\" size=\"larger\">", str, "</span>", NULL);
 	g_free (str);
