@@ -759,7 +759,7 @@ gedit_mdi_drag_data_received_handler (GtkWidget *widget, GdkDragContext *context
 	if (file_list == NULL)
 		return;
 
-	gedit_file_open_uri_list (file_list, 0, FALSE);	
+	gedit_file_open_uri_list (file_list, NULL, 0, FALSE);	
 	
 	g_slist_foreach (file_list, (GFunc)g_free, NULL);	
 	g_slist_free (file_list);
@@ -1437,10 +1437,7 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 	else
 		bonobo_ui_component_set_prop (ui_component, "/menu/View/HighlightMode",
 					      "sensitive", "0", NULL);
-
-	gedit_menus_set_verb_sensitive (ui_component, "/commands/DocumentsMoveToNewWindow",
-				(bonobo_mdi_n_children_for_window (active_window) > 1) ? TRUE : FALSE);
-
+	
 	doc = GEDIT_MDI_CHILD (active_child)->document;
 	g_return_if_fail (doc != NULL);
 	
@@ -1476,7 +1473,6 @@ gedit_mdi_set_active_window_verbs_sensitivity (BonoboMDI *mdi)
 	}
 
 end:
-
 	switch (gedit_mdi_get_state (GEDIT_MDI (mdi)))
 	{
 		case GEDIT_STATE_LOADING:
@@ -1503,6 +1499,9 @@ end:
 			break;
 	}
 
+	gedit_menus_set_verb_sensitive (ui_component, "/commands/DocumentsMoveToNewWindow",
+				(bonobo_mdi_n_views_for_window (active_window) > 1) ? TRUE : FALSE);
+
 	bonobo_ui_component_thaw (ui_component, NULL);
 }
 
